@@ -12,7 +12,7 @@ use feature ();
 package Zydeco;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.606';
+our $VERSION   = '0.607';
 
 use Keyword::Simple ();
 use PPR;
@@ -2327,7 +2327,7 @@ sub _include {
 #{
 #	package Zydeco::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.606';
+#	our $VERSION   = '0.607';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -2338,7 +2338,7 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.606';
+#	our $VERSION   = '0.607';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -2351,12 +2351,12 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.606';
+#	our $VERSION   = '0.607';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	
 #	package Zydeco::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.606';
+#	our $VERSION   = '0.607';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -2370,7 +2370,7 @@ sub _include {
 #
 #	package Zydeco::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.606';
+#	our $VERSION   = '0.607';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -2404,7 +2404,7 @@ sub anonymous_package {
 	require Module::Runtime;
 	$INC{Module::Runtime::module_notional_filename($qname)} = __FILE__;
 	#return bless(\$qname, "Zydeco::Anonymous::".ucfirst($kind));
-	return $qname;
+	return MooX::Press::make_absolute_package_name($qname);
 }
 
 sub anonymous_generator {
@@ -2419,7 +2419,7 @@ sub anonymous_generator {
 	require Module::Runtime;
 	$INC{Module::Runtime::module_notional_filename($qname)} = __FILE__;
 	#return bless(\$qname, "Zydeco::Anonymous::Parameterizable".ucfirst($kind));
-	return $qname;
+	return MooX::Press::make_absolute_package_name($qname);
 }
 
 1;
